@@ -721,9 +721,14 @@ class enigma_ui
         // get user's identities
         $identities = $this->rc->user->list_identities(null, true);
         $checkbox   = new html_checkbox(array('name' => 'identity[]'));
-        foreach ((array) $identities as $idx => $ident) {
+
+        $plugin     = $this->rc->plugins->exec_hook('enigma_user_identities', array('identities' => $identities));
+        $identities = $plugin['identities'];
+
+        foreach ($identities as $idx => $ident) {
             $name = empty($ident['name']) ? ($ident['email']) : $ident['ident'];
-            $identities[$idx] = html::label(null, $checkbox->show($name, array('value' => $name)) . rcube::Q($name));
+            $attr = array('value' => $idx, 'data-name' => $ident['name'], 'data-email' => $ident['email']);
+            $identities[$idx] = html::label(null, $checkbox->show($idx, $attr) . rcube::Q($name));
         }
 
         $table->add('title', html::label('key-name', rcube::Q($this->enigma->gettext('newkeyident'))));
@@ -889,6 +894,9 @@ class enigma_ui
                     $msg     = rcube::Q($this->enigma->gettext($label));
                     $this->password_prompt($status);
                 }
+                else if ($code == enigma_error::NOMDC) {
+                    $msg = rcube::Q($this->enigma->gettext('decryptnomdc'));
+                }
                 else {
                     $msg = rcube::Q($this->enigma->gettext('decrypterror'));
                 }
