@@ -296,14 +296,10 @@ class rcube_cache
             }
         }
         else {
-            $sql_result = $this->db->limitquery(
-                "SELECT `data`, `cache_key`".
-                " FROM {$this->table}".
-                " WHERE `user_id` = ? AND `cache_key` = ?".
-                // for better performance we allow more records for one key
-                // get the newer one
-                " ORDER BY `created` DESC",
-                0, 1, $this->userid, $this->prefix.'.'.$key);
+            $sql_result = $this->db->query(
+                "SELECT `data`, `cache_key` FROM {$this->table}"
+                . " WHERE `user_id` = ? AND `cache_key` = ?",
+                $this->userid, $this->prefix.'.'.$key);
 
             if ($sql_arr = $this->db->fetch_assoc($sql_result)) {
                 if (strlen($sql_arr['data']) > 0) {
@@ -311,6 +307,8 @@ class rcube_cache
                     $data   = $this->unserialize($sql_arr['data']);
                 }
 
+                $this->db->reset();
+
                 if ($nostore) {
                     return $data;
                 }
@@ -365,42 +363,44 @@ class rcube_cache
             return $result;
         }
 
-        $key_exists = array_key_exists($key, $this->cache_sums);
-        $key        = $this->prefix . '.' . $key;
+        $db_key = $this->prefix . '.' . $key;
 
         // Remove NULL rows (here we don't need to check if the record exist)
         if ($data == 'N;') {
-            $this->db->query(
+            $result = $this->db->query(
                 "DELETE FROM {$this->table}".
                 " WHERE `user_id` = ? AND `cache_key` = ?",
-                $this->userid, $key);
+                $this->userid, $db_key);
 
-            return true;
+            return !$this->db->is_error($result);
         }
 
-        // update existing cache record
-        if ($key_exists) {
+        $key_exists = array_key_exists($key, $this->cache_sums);
+        $expires    = $this->ttl ? $this->db->now($this->ttl) : 'NULL';
+
+        if (!$key_exists) {
+            // Try INSERT temporarily ignoring "duplicate key" errors
+            $this->db->set_option('ignore_key_errors', true);
+
             $result = $this->db->query(
-                "UPDATE {$this->table}".
-                " SET `created` = " . $this->db->now().
-                    ", `expires` = " . ($this->ttl ? $this->db->now($this->ttl) : 'NULL').
-                    ", `data` = ?".
-                " WHERE `user_id` = ?".
-                " AND `cache_key` = ?",
-                $data, $this->userid, $key);
-        }
-        // add new cache record
-        else {
-            // for better performance we allow more records for one key
-            // so, no need to check if record exist (see rcube_cache::read_record())
-            $result = $this->db->query(
-                "INSERT INTO {$this->table}".
-                " (`created`, `expires`, `user_id`, `cache_key`, `data`)".
-                " VALUES (" . $this->db->now() . ", " . ($this->ttl ? $this->db->now($this->ttl) : 'NULL') . ", ?, ?, ?)",
-                $this->userid, $key, $data);
+                "INSERT INTO {$this->table} (`expires`, `user_id`, `cache_key`, `data`)"
+                . " VALUES ($expires, ?, ?, ?)",
+                $this->userid, $db_key, $data);
+
+            $this->db->set_option('ignore_key_errors', false);
         }
 
-        return $this->db->affected_rows($result);
+        // otherwise try UPDATE
+        if (!isset($result) || !($count = $this->db->affected_rows($result))) {
+            $result = $this->db->query(
+                "UPDATE {$this->table} SET `expires` = $expires, `data` = ?"
+                . " WHERE `user_id` = ? AND `cache_key` = ?",
+                $data, $this->userid, $db_key);
+
+            $count = $this->db->affected_rows($result);
+        }
+
+        return $count > 0;
     }
 
     /**
