@@ -1,6 +1,6 @@
 <?php
 
-/*
+/**
  +-----------------------------------------------------------------------+
  | This file is part of the Roundcube Webmail client                     |
  | Copyright (C) 2005-2011, The Roundcube Dev Team                       |
@@ -47,7 +47,6 @@ class rcube_result_thread
         $this->init($data);
     }
 
-
     /**
      * Initializes object with IMAP command response
      *
@@ -83,7 +82,6 @@ class rcube_result_thread
         $this->raw_data = $this->parse_thread($data);
     }
 
-
     /**
      * Checks the result from IMAP command
      *
@@ -91,10 +89,9 @@ class rcube_result_thread
      */
     public function is_error()
     {
-        return $this->raw_data === null ? true : false;
+        return $this->raw_data === null;
     }
 
-
     /**
      * Checks if the result is empty
      *
@@ -102,10 +99,9 @@ class rcube_result_thread
      */
     public function is_empty()
     {
-        return empty($this->raw_data) ? true : false;
+        return empty($this->raw_data);
     }
 
-
     /**
      * Returns number of elements (threads) in the result
      *
@@ -129,7 +125,6 @@ class rcube_result_thread
         return $this->meta['count'];
     }
 
-
     /**
      * Returns number of all messages in the result
      *
@@ -155,7 +150,6 @@ class rcube_result_thread
         return $this->meta['messages'];
     }
 
-
     /**
      * Returns maximum message identifier in the result
      *
@@ -169,7 +163,6 @@ class rcube_result_thread
         return $this->meta['max'];
     }
 
-
     /**
      * Returns minimum message identifier in the result
      *
@@ -183,7 +176,6 @@ class rcube_result_thread
         return $this->meta['min'];
     }
 
-
     /**
      * Slices data set.
      *
@@ -200,7 +192,6 @@ class rcube_result_thread
         $this->raw_data      = implode(self::SEPARATOR_ELEMENT, $data);
     }
 
-
     /**
      * Filters data set. Removes threads not listed in $roots list.
      *
@@ -240,7 +231,6 @@ class rcube_result_thread
         $this->raw_data = ltrim($result, self::SEPARATOR_ELEMENT);
     }
 
-
     /**
      * Reverts order of elements in the result
      */
@@ -252,25 +242,13 @@ class rcube_result_thread
             return;
         }
 
+        $data = explode(self::SEPARATOR_ELEMENT, $this->raw_data);
+        $data = array_reverse($data);
+        $this->raw_data = implode(self::SEPARATOR_ELEMENT, $data);
+
         $this->meta['pos'] = array();
-        $datalen = strlen($this->raw_data);
-        $result  = '';
-        $start   = 0;
-
-        while (($pos = @strpos($this->raw_data, self::SEPARATOR_ELEMENT, $start))
-            || ($start < $datalen && ($pos = $datalen))
-        ) {
-            $len   = $pos - $start;
-            $elem  = substr($this->raw_data, $start, $len);
-            $start = $pos + 1;
-
-            $result = $elem . self::SEPARATOR_ELEMENT . $result;
-        }
-
-        $this->raw_data = rtrim($result, self::SEPARATOR_ELEMENT);
     }
 
-
     /**
      * Check if the given message ID exists in the object
      *
@@ -314,7 +292,6 @@ class rcube_result_thread
         return false;
     }
 
-
     /**
      * Return IDs of all messages in the result. Threaded data will be flattened.
      *
@@ -333,7 +310,6 @@ class rcube_result_thread
         return preg_split($regexp, $this->raw_data);
     }
 
-
     /**
      * Return all messages in the result.
      *
@@ -348,7 +324,6 @@ class rcube_result_thread
         return rcube_imap_generic::compressMessageSet($this->get());
     }
 
-
     /**
      * Return result element at specified index (all messages, not roots)
      *
@@ -418,17 +393,16 @@ class rcube_result_thread
         return $data[$index];
     }
 
-
     /**
      * Returns response parameters e.g. MAILBOX, ORDER
      *
-     * @param string $param  Parameter name
+     * @param string $param Parameter name
      *
      * @return array|string Response parameters or parameter value
      */
     public function get_parameters($param=null)
     {
-        $params = $this->params;
+        $params = array();
         $params['MAILBOX'] = $this->mailbox;
         $params['ORDER']   = $this->order;
 
@@ -439,7 +413,6 @@ class rcube_result_thread
         return $params;
     }
 
-
     /**
      * THREAD=REFS sorting implementation (based on provided index)
      *
@@ -509,7 +482,6 @@ class rcube_result_thread
         $this->raw_data = implode(self::SEPARATOR_ELEMENT, $result);
     }
 
-
     /**
      * Returns data as tree
      *
@@ -534,7 +506,6 @@ class rcube_result_thread
         return $result;
     }
 
-
     /**
      * Returns thread depth and children data
      *
@@ -551,7 +522,6 @@ class rcube_result_thread
         return array($depth, $children);
     }
 
-
     /**
      * Creates 'depth' and 'children' arrays from stored thread 'tree' data.
      */
@@ -567,7 +537,6 @@ class rcube_result_thread
         }
     }
 
-
     /**
      * Converts part of the raw thread into an array
      */
@@ -590,7 +559,6 @@ class rcube_result_thread
         return $result;
     }
 
-
     /**
      * IMAP THREAD response parser
      */
